==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridSelectedCellRangesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellRangesChangedEventArgsDescription } from "./GridSelectedCellRangesChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedCellRangesChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedCellRangesChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedCellRangesChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedCellRangesChangedEventArgsDescriptionMetadata.c(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        a.item("AddedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        a.item("RemovedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        a.item("UpdatedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
    };
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedCellRangesChangedEventArgsDescriptionMetadata.b(a);
        a.u("GridSelectedCellRangesChangedEventArgs", function () { return new GridSelectedCellRangesChangedEventArgsDescription(); });
        a.t("GridSelectedCellRangesChangedEventArgs", GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellRangesChangedEventArgsDescriptionMetadata, 'GridSelectedCellRangesChangedEventArgsDescriptionMetadata');
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellRangesChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedCellRangesChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridSelectedCellRangesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellRangesChangedEventArgsDescription } from "./GridSelectedCellRangesChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedCellRangesChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedCellRangesChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedCellRangesChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedCellRangesChangedEventArgsDescriptionMetadata.c(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        a.item("AddedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        a.item("RemovedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        a.item("UpdatedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
    };
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedCellRangesChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSelectedCellRangesChangedEventArgs", function () { return new GridSelectedCellRangesChangedEventArgsDescription(); });
        a.z("GridSelectedCellRangesChangedEventArgs", GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellRangesChangedEventArgsDescriptionMetadata, 'GridSelectedCellRangesChangedEventArgsDescriptionMetadata');
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellRangesChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedCellRangesChangedEventArgsDescriptionMetadata };
